<?php

namespace Drupal\mail_box_management\Server\Imap;

use IMAP\Connection;
use Drupal\Core\Config\Config;

/**
 * File ImapConnection.
 *
 * @file
 * ImapConnection.php contains class ImapConnection
 */

/**
 * ImapConnection is responsible for imap connectivity.
 *
 * @class
 * ImapConnection is responsible for imap connectivity.
 */
class ImapConnection {

  /**
   * Username for imap server.
   *
   * @var \Drupal\Core\Config\Config
   */
  public Config $configUsername;

  /**
   * Password for imap server.
   *
   * @var \Drupal\Core\Config\Config
   */
  public Config $configPassword;

  /**
   * Hostname for imap server.
   *
   * @var \Drupal\Core\Config\Config
   */
  public Config $configHostname;

  /**
   * Port for imap server.
   *
   * @var \Drupal\Core\Config\Config
   */
  public Config $configPort;

  /**
   * IMAP connection.
   *
   * @var false|\IMAP\Connection
   */
  public false|Connection $imapConnection;

  /**
   * Secure SSL or TLS for imap.
   *
   * @var \Drupal\Core\Config\Config
   */
  public Config $secure;

  /**
   * Connection string namespace.
   *
   * @var string
   */
  public string $hostname;

  /**
   * Initialize connection.
   */
  public function __construct() {
    $config_helper = mail_box_management_service('mail_box_management.config');
    $this->configHostname = $config_helper->get('mail_box_management.imap_server_host');
    $this->configUsername = $config_helper->get('mail_box_management.imap_server_user_name');
    $this->configPassword = $config_helper->get('mail_box_management.imap_server_password');
    $this->configPort = $config_helper->get('mail_box_management.imap_server_port');
    $this->secure = $config_helper->get('mail_box_management.imap_server_secure');

    if (!empty($this->configHostname->get('imap_server_host')) &&
      !empty($this->configPort->get('imap_server_port')) &&
      !empty($this->configUsername->get('imap_server_user_name')) &&
      !empty($this->configPassword->get('imap_server_password')) &&
      !empty($this->secure->get('imap_server_secure'))
    ) {
      $this->hostname = "{{$this->configHostname->get('imap_server_host')}:{$this->configPort->get('imap_server_port')}/imap/{$this->secure->get('imap_server_secure')}}";
      if ($con = imap_open($this->hostname, $this->configUsername->get('imap_server_user_name'), $this->configPassword->get('imap_server_password'))) {
        $this->imapConnection = $con;
      }
    }

  }

  /**
   * Destroy connection.
   */
  public function __destruct() {
    unset($this->imapConnection);
  }

}
